@@ -49,15 +49,16 @@
 
 package com.openexchange.util.activator.impl;
 
+import static com.openexchange.util.custom.base.NullUtil.emptySet;
+import static com.openexchange.util.custom.base.NullUtil.immutableCopyOf;
 import static com.openexchange.util.custom.base.NullUtil.notNull;
 import java.util.Arrays;
 import java.util.HashSet;
 import java.util.Objects;
 import java.util.Set;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
 import com.google.common.base.MoreObjects;
 import com.google.common.collect.ImmutableSet;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.util.activator.ServiceDependencies;
 
 
@@ -67,14 +68,13 @@ import com.openexchange.util.activator.ServiceDependencies;
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  * @since v1.0.2
  */
-@ParametersAreNonnullByDefault
 public final class ImmutableServiceDependencies implements ServiceDependencies {
     
     private static final ImmutableServiceDependencies EMPTY = new ImmutableServiceDependencies(
-        ImmutableSet.<MandatoryServiceDependency<?>>of(),
-        ImmutableSet.<OptionalServiceDependency<?>>of(),
-        ImmutableSet.<Class<?>>of(),
-        ImmutableSet.<Class<?>>of()
+        emptySet(),
+        emptySet(),
+        emptySet(),
+        emptySet()
     );
     
     public static ServiceDependencies empty() {
@@ -97,10 +97,10 @@ public final class ImmutableServiceDependencies implements ServiceDependencies {
             serviceListingsBuilder.addAll(d.serviceListingClasses());
         }
         return new ImmutableServiceDependencies(
-            ImmutableSet.copyOf(mandatoryServiceDependenciesBuilder),
-            ImmutableSet.copyOf(optionalServiceDependenciesBuilder),
-            ImmutableSet.copyOf(serviceSetsBuilder),
-            ImmutableSet.copyOf(serviceListingsBuilder)
+            immutableCopyOf(mandatoryServiceDependenciesBuilder),
+            immutableCopyOf(optionalServiceDependenciesBuilder),
+            immutableCopyOf(serviceSetsBuilder),
+            immutableCopyOf(serviceListingsBuilder)
         );
     }
     
@@ -171,7 +171,7 @@ public final class ImmutableServiceDependencies implements ServiceDependencies {
     }
     
     @Override
-    public String toString() {
+    public @Nullable String toString() {
         return MoreObjects.toStringHelper(this)
         .add("mandatoryDependencies", mandatoryDependencies)
         .add("optionalDependencies", optionalDependencies)
