@@ -49,18 +49,18 @@
 
 package com.openexchange.util.activator.impl;
 
+import static com.openexchange.util.custom.base.NullUtil.immutableSetCopyOf;
 import java.lang.reflect.Constructor;
 import java.util.Dictionary;
 import java.util.HashSet;
 import java.util.Set;
-import javax.annotation.Nullable;
-import javax.annotation.ParametersAreNonnullByDefault;
 import javax.annotation.concurrent.Immutable;
 import javax.servlet.http.HttpServlet;
 import org.osgi.framework.BundleContext;
 import org.osgi.service.http.HttpService;
 import org.osgi.util.tracker.ServiceTrackerCustomizer;
 import com.google.common.collect.ImmutableSet;
+import com.openexchange.annotation.Nullable;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.util.activator.ServiceRegistrationHandler;
 
@@ -72,7 +72,6 @@ import com.openexchange.util.activator.ServiceRegistrationHandler;
  * @param <S>
  * @param <T>
  */
-@ParametersAreNonnullByDefault
 @Immutable
 public final class ServletClassServiceWithDependencies<T extends HttpServlet> extends ClassServiceWithDependenciesTemplate<HttpServlet, T> {
     
@@ -89,7 +88,7 @@ public final class ServletClassServiceWithDependencies<T extends HttpServlet> ex
         return new ServletClassServiceWithDependencies<Y>(path,
             scan.constructor,
             serviceInstanceClass,
-            ImmutableSet.copyOf(mandatoryDeps),
+            immutableSetCopyOf(mandatoryDeps),
             scan.optionalDependencies,
             scan.serviceSets,
             scan.serviceListings
