@@ -49,7 +49,7 @@
 
 package com.openexchange.util.activator.impl;
 
-import javax.annotation.ParametersAreNonnullByDefault;
+
 import com.openexchange.groupware.update.DefaultUpdateTaskProviderService;
 import com.openexchange.groupware.update.UpdateTaskProviderService;
 import com.openexchange.groupware.update.UpdateTaskV2;
@@ -62,7 +62,6 @@ import com.openexchange.util.activator.ServiceDependencyResolver;
  * @author <a href="mailto:pascal.bleser@open-xchange.com">Pascal Bleser</a>
  * @since v1.0.2
  */
-@ParametersAreNonnullByDefault
 public final class UpdateTaskServiceWithDependencies<U extends UpdateTaskV2>
 extends ServiceWithDependenciesTemplate<UpdateTaskProviderService, DefaultUpdateTaskProviderService> {
     
